#!/bin/csh 
#SBATCH --job-name=DMPC_0.1M_NaCl_30C
#SBATCH --time=36:00:00
#SBATCH --nodes=2
#SBATCH --ntasks-per-node=24
#SBATCH --partition=parallel

setenv CONV_RSH ssh
unset noclobber

# Set Run Length per file
set simt = 2500000

echo Running on host `hostname`
echo Time is `date`
echo Directory is `pwd`
echo This jobs runs on the following processors:

cd $SLURM_SUBMIT_DIR
echo $SLURM_SUBMIT_DIR
pwd

#setenv PBS_NODEFILE `generate_pbs_nodefile`

# Creates nodelist
#set namd = "/homes/jbklauda/namd/NAMD_2.9_Linux-x86_64-TCP/namd2"
#set ch = "/homes/jbklauda/namd/NAMD_2.9_Linux-x86_64-TCP/charmrun"
#set NODELIST = namd2.nodelist
#set nodes = `cat $PBS_NODEFILE`
#cat $PBS_NODEFILE > nodelist
#echo group main >! $NODELIST
#foreach node ( $nodes )
#  echo host $node >> $NODELIST
#end

@ krun = 1

if ( -e start.time) then
 @ start = `cat start.time `
else
 @ start = 0                  
endif

#### JEC NODELIST=$SLURM_JOBID.nodes
#echo $SLURM_NODELIST
#set NODELIST=$SLURM_JOBID.nodes
#echo "host $SLURM_NODELIST" >> $NODELIST

#echo "New hostlist", $NODELIST
### JEC namd2 +p24 +devices 0,1,2,3 dyn.inp > dyn.out

# Create a new input file
rm -f dyn.inp
cat dyn-1.inp > dyn.inp
echo "firsttimestep     $start; " >> dyn.inp
cat dyn-2.inp >> dyn.inp

set one = one
echo $one > test.file
echo $one
# Execution of the script
module load namd/2.12-ibverbs
module unload openmpi/intel/1.8.4

# create environment for namd ibverbs to run on more than one node
      
scontrol show hostnames "$SLURM_JOB_NODELIST" > JOBNODES
cat JOBNODES
set NODELIST=$SLURM_JOBID.nodes
echo group main >! $NODELIST
foreach i (`cat JOBNODES`) 
        echo host $i >> $NODELIST
end
     
###export CONV_RSH=ssh
echo $SLURM_JOB_NUM_NODES
echo $SLURM_NTASKS_PER_NODE
@ NUMPROCS = $SLURM_JOB_NUM_NODES * $SLURM_NTASKS_PER_NODE
echo $NUMPROCS
date
#
#  Run namd using SLURM MPIEXEC instead of ssh
charmrun  `which namd2` ++mpiexec-no-n  +p$NUMPROCS ++verbose ++nodelist $NODELIST dyn.inp > dyn.out
date
echo $one >> test.file
echo $one

set okay = true
# TEST FOR EXISTENCE, THEN NONZERO LENGTH OF OUTPUT FILES
if ( -e dyn.coor && -e dyn.dcd ) then
 @ tsz = `/bin/ls -s dyn.dcd | awk '{print $1}'`
 @ nrm = `grep 'WallClock' dyn.out | wc -l`
 @ nrm1 = `grep 'ERROR: ' dyn.out | wc -l`
 
echo $tsz >> test.file
echo $tsz
echo $nrm >> test.file
echo $nrm
 if ( $tsz > 0 && $nrm == 1 && $nrm1 < 1 ) then
# SUCCESSFUL RUN; COPY RESTART FILE
#  cp dyn.res dyn.rea
# DETERMINE RUN NUMBER
  if ( -e next.seqno ) then
   @ i = `cat next.seqno` 
  else
   @ i = 1
  endif
# Change the new Start Time
@ start = $start + $simt
echo $start > start.time

# ENABLE/DISABLE ANALYSIS EVERY 2ND RUN
#  if ( 0 == $i % 2 ) qsub -l nodes=1 chk.csh
# NUMBER THE OUTPUT FILES; CHANGE EXTENSIONS TO SUIT APPLICATION
  foreach fil ( out coor xsc xst vel dcd )
   mv dyn.$fil dyn$i.$fil
  end
  cp dyn$i.xsc dyn.xsc
  cp dyn$i.coor dyn.coor
  cp dyn$i.vel dyn.vel
  gzip dyn$i.out dyn$i.coor dyn$i.xsc dyn$i.vel dyn$i.xst
# CONDITIONAL END CHECK
  if ( -e last.seqno ) then
    @ l = `cat last.seqno`
    if ( $i == $l ) then
      @ i += 1
      echo $i > next.seqno 
      exit
    endif
  endif

# SUBMIT THE NEXT JOB
#  rm ~/namd.$PBS_JOBID
  sleep 5m
  @ i += 1
  echo $i > next.seqno
  ./dyn.scr
  exit
else
# FILE DOESN'T EXIST
 set okay = false
endif
# FILE DOESN'T EXIST
 set okay = false
endif

# TEST FOR CHARMM RUN FAILED; CREATE .ERR FILE WITH TIMESTAMP
if ( $okay == false ) then
 set ts = `date +%m%d.%H%M`
 mv dyn.out dyn.err.$ts
 exit(201)
endif

end

